==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__24ButtonActionListener.h <==
// public class javax.swing.plaf.basic.BasicOptionPaneUI$ButtonActionListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d6fed143d066ef20 javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$method$_init$0b01dde9bd8717a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI$object *, jint);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs {
	jint	buttonIndex;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__24ButtonActionListener.h <==
// public class javax.swing.plaf.basic.BasicOptionPaneUI$ButtonActionListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c1ac82ffcae6c753 javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$method$_init$0b01dde9bd8717a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs {
	jint	buttonIndex;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24ButtonActionListener_H_ */
